About CWI | CWI

# About CWI

Founded in 1946, CWI is the national research center for mathematics and computer science in the Netherlands. More than 170 full professors have come from CWI, of whom 120 still are active. CWI's strength is the discovery and development of new ideas, and the transfer of knowledge to academia and to Dutch and European industry. This results in importance for our economy, from payment systems and cryptography to telecommunication and the stock market, from public transport and internet to water management and meteorology.

An international network

With its 55 permanent research staff, 40 postdocs and 65 PhD students, CWI lies at the heart of European research in mathematics and computer science. Researchers at CWI are able to fully concentrate their efforts on their scientific work, and to build an international network of peers. More than half of the permanent research staff maintains close contact with universities as part-time professors. The personal and institutional research networks strengthen CWI's positions and serve as a magnet for attracting talent. The CWI researchers come from more than 25 countries world-wide.

A source of pride

CWI was a birthplace of the world-wide internet. Cwi.nl was the first national domain name ever issued anywhere. CWI helped develop the wing of the Fokker Friendship - chosen the most beautiful Dutch design of the 20th century. The popular language Python was invented at CWI, the language in which Google was developed. CWI applied combinatorial algorithms to the scheduling of the Dutch railway system. XML-databases were build to the needs of the Netherlands Forensic Institute and 3D visualization techniques to better detect cancer tumors.

More facts

- CWI is one of the founding members of the European Research Consortium for Informatics and Mathematics, ERCIM.
- CWI participates in the Telematics Institute and cooperates with many companies, universities and technological institutes.
- CWI is funded for 70 percent by the Netherlands Organisation for Scientific Research, NWO. The remaining 30 percent is obtained through national and international programmes and contract research commissioned by industry.
- CWI has several spin-off companies, based on results of CWI's research.
- CWI manages the Benelux Office of the World Wide Web Consortium (W3C).
- CWI forms with the neighbouring institutes the Science Park Amsterdam, with very good facilities such as Amsterdam Internet Exchange and access to the Gigabit backbone.
- CWI organizes scientific conferences, lectures and other events.

- nl